@@ -1,7 +1,7 @@
 package CPAN::Reporter::PrereqCheck;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.05'; 
+$VERSION = '1.06'; 
 
 use ExtUtils::MakeMaker;
 use CPAN::Version;
@@ -31,10 +31,12 @@ sub _run {
             if (@packpath == 1 && $packpath[0] eq "readline.pm") {
                 unshift @packpath, "Term", "ReadLine"; # historical reasons
             }
+            INCDIR:
             foreach my $dir (@INC) {
                 my $pmfile = File::Spec->catfile($dir,@packpath);
                 if (-f $pmfile){
                     $inst_file = $pmfile;
+                    last INCDIR;
                 }
             }
             
